@@ -1,6 +1,7 @@
 import functools
 import logging
 import math
+import os
 import subprocess
 import tempfile
 from pathlib import Path
@@ -29,9 +30,9 @@ def bpmn_to_image(bpmn_path: Path, png_path: Path, shift_to_origin=False):
         such that its top-left is close to (0,0), and does not render elements at exact BPMNDI positions.
         when set to False, we undo this operation.
     """
-    cmd = ["bpmn-to-image", "--no-title", "--no-footer", f"{bpmn_path}:{png_path}"]
-    _logger.debug("Executing: %s", " ".join(cmd))
-    subprocess.run(cmd, check=True, capture_output=True)
+    cmd = f"bpmn-to-image --no-title --no-footer {bpmn_path}{os.pathsep}{png_path}"
+    _logger.info("Executing: %s", cmd)
+    subprocess.run(cmd, check=True, capture_output=True, shell=True)
     img: Image.Image = Image.open(png_path)
 
     if not shift_to_origin:
@@ -132,6 +133,7 @@ def _get_approx_bpmn_bounding_box(bpmn_path):
 
 def get_bpmn_bounding_box(bpmn_path):
     """
+    NOTE: this does not apply rescaling to image width as done in BpmnParser.scale_anns_to_img_width_
     :return: the smallest bounding box that covers all diagram symbols
     """
     document = etree.parse(str(bpmn_path))
